pub enum ProxyCsvRowReaderErrorKind {
IoError(Error),
InvalidRow(String),
}Available on crate feature
csv only.Expand description
The kind of error that can occur when reading a Proxy CSV row.
Variants
IoError(Error)
An I/O error occurred while reading the CSV row.
InvalidRow(String)
The CSV row is invalid, and could not be parsed.