pub struct MemoryProxyDBInsertError { /* private fields */ }Available on crate feature
memory-db only.Expand description
The error type that can be returned by MemoryProxyDB when some of the proxies
could not be inserted due to a proxy that had a duplicate key or was invalid for some other reason.
Implementations
Sourceimpl MemoryProxyDBInsertError
impl MemoryProxyDBInsertError
Sourcepub fn kind(&self) -> MemoryProxyDBInsertErrorKind
pub fn kind(&self) -> MemoryProxyDBInsertErrorKind
Returns the kind of error that MemoryProxyDBInsertError represents.
Sourcepub fn into_proxies(self) -> Vec<Proxy>
pub fn into_proxies(self) -> Vec<Proxy>
Consumes the error and returns the proxies that were not inserted.