Proxy

Struct Proxy 

pub struct Proxy {
Show 18 fields pub id: NonEmptyStr, pub address: ProxyAddress, pub tcp: bool, pub udp: bool, pub http: bool, pub https: bool, pub socks5: bool, pub socks5h: bool, pub datacenter: bool, pub residential: bool, pub mobile: bool, pub pool_id: Option<StringFilter>, pub continent: Option<StringFilter>, pub country: Option<StringFilter>, pub state: Option<StringFilter>, pub city: Option<StringFilter>, pub carrier: Option<StringFilter>, pub asn: Option<Asn>,
}
A proxy record returned by a ProxyDB.

Fields

id: NonEmptyStr

Unique identifier of the proxy.

address: ProxyAddress

The address to be used to connect to the proxy, including credentials if needed.

tcp: bool

True if the proxy supports TCP connections.

udp: bool

True if the proxy supports UDP connections.

http: bool

http-proxy enabled

https: bool

https-proxy enabled

socks5: bool

socks5-proxy enabled

socks5h: bool

socks5h-proxy enabled

datacenter: bool

Proxy is located in a datacenter.

residential: bool

Proxy’s IP is labeled as residential.

mobile: bool

Proxy’s IP originates from a mobile network.

pool_id: Option<StringFilter>

Pool ID of the proxy.

continent: Option<StringFilter>

Continent of the proxy.

country: Option<StringFilter>

Country of the proxy.

state: Option<StringFilter>

State of the proxy.

city: Option<StringFilter>

City of the proxy.

carrier: Option<StringFilter>

Mobile carrier of the proxy.

asn: Option<Asn>

Autonomous System Number (ASN).

Implementations

Source

impl Proxy

pub fn is_match(&self, ctx: &ProxyContext, filter: &ProxyFilter) -> bool

Check if the proxy is a match for the givenProxyContext and ProxyFilter.