pub struct ProxyDBLayer<D, P, F> { /* private fields */ }Expand description
A Layer which wraps an inner Service to resolve proxy candidates
based on the input extensions and publish route-specific proxy metadata.
See the crate docs for examples and more info on the usage of this service.
Implementations
Sourceimpl<D> ProxyDBLayer<D, bool, ()>
impl<D> ProxyDBLayer<D, bool, ()>
Sourcepub const fn new(db: D) -> Self
pub const fn new(db: D) -> Self
Create a new ProxyDBLayer with the given ProxyDB.
Sourceimpl<D, P, F> ProxyDBLayer<D, P, F>
impl<D, P, F> ProxyDBLayer<D, P, F>
Sourcepub fn maybe_with_max_proxies(self, max_proxies: Option<NonZeroUsize>) -> Self
pub fn maybe_with_max_proxies(self, max_proxies: Option<NonZeroUsize>) -> Self
Limit the number of proxy candidates published for one query.
The default is DEFAULT_PROXY_DB_MAX_PROXIES. Use
Self::without_max_proxies for an unbounded query.
Sourcepub fn maybe_set_max_proxies(
&mut self,
max_proxies: Option<NonZeroUsize>,
) -> &mut Self
pub fn maybe_set_max_proxies( &mut self, max_proxies: Option<NonZeroUsize>, ) -> &mut Self
Limit the number of proxy candidates published for one query.
The default is DEFAULT_PROXY_DB_MAX_PROXIES. Use
Self::without_max_proxies for an unbounded query.
Sourcepub fn with_max_proxies(self, max_proxies: NonZeroUsize) -> Self
pub fn with_max_proxies(self, max_proxies: NonZeroUsize) -> Self
Limit the number of proxy candidates published for one query.
The default is DEFAULT_PROXY_DB_MAX_PROXIES. Use
Self::without_max_proxies for an unbounded query.
Sourcepub fn set_max_proxies(&mut self, max_proxies: NonZeroUsize) -> &mut Self
pub fn set_max_proxies(&mut self, max_proxies: NonZeroUsize) -> &mut Self
Limit the number of proxy candidates published for one query.
The default is DEFAULT_PROXY_DB_MAX_PROXIES. Use
Self::without_max_proxies for an unbounded query.
Sourcepub fn without_max_proxies(self) -> Self
pub fn without_max_proxies(self) -> Self
Limit the number of proxy candidates published for one query.
The default is DEFAULT_PROXY_DB_MAX_PROXIES. Use
Self::without_max_proxies for an unbounded query.
Sourcepub fn unset_max_proxies(&mut self) -> &mut Self
pub fn unset_max_proxies(&mut self) -> &mut Self
Limit the number of proxy candidates published for one query.
The default is DEFAULT_PROXY_DB_MAX_PROXIES. Use
Self::without_max_proxies for an unbounded query.
Sourcepub fn with_filter_mode(self, mode: ProxyFilterMode) -> Self
pub fn with_filter_mode(self, mode: ProxyFilterMode) -> Self
Set a ProxyFilterMode to define the behaviour surrounding
ProxyFilter usage, e.g. if a proxy filter is required to be available or not,
or what to do if it is optional and not available.
Sourcepub fn set_filter_mode(&mut self, mode: ProxyFilterMode) -> &mut Self
pub fn set_filter_mode(&mut self, mode: ProxyFilterMode) -> &mut Self
Set a ProxyFilterMode to define the behaviour surrounding
ProxyFilter usage, e.g. if a proxy filter is required to be available or not,
or what to do if it is optional and not available.
Sourcepub fn with_single_proxy(self, single_proxy: bool) -> Self
pub fn with_single_proxy(self, single_proxy: bool) -> Self
Select and insert only one proxy instead of publishing every match as an ordered route plan. This uses the database’s singular-selection semantics, preserves legacy pre-fallback behaviour, and is disabled by default.
Sourcepub fn set_single_proxy(&mut self, single_proxy: bool) -> &mut Self
pub fn set_single_proxy(&mut self, single_proxy: bool) -> &mut Self
Select and insert only one proxy instead of publishing every match as an ordered route plan. This uses the database’s singular-selection semantics, preserves legacy pre-fallback behaviour, and is disabled by default.
Sourcepub fn with_overwrite_proxy(self, overwrite_proxy: bool) -> Self
pub fn with_overwrite_proxy(self, overwrite_proxy: bool) -> Self
Overwrite an existing singular ProxyRoute with the selected
proxy route or route plan. This is disabled by default in both
plural and singular selection modes.
Sourcepub fn set_overwrite_proxy(&mut self, overwrite_proxy: bool) -> &mut Self
pub fn set_overwrite_proxy(&mut self, overwrite_proxy: bool) -> &mut Self
Overwrite an existing singular ProxyRoute with the selected
proxy route or route plan. This is disabled by default in both
plural and singular selection modes.
Sourcepub fn with_select_predicate<Predicate>(
self,
p: Predicate,
) -> ProxyDBLayer<D, Predicate, F>
pub fn with_select_predicate<Predicate>( self, p: Predicate, ) -> ProxyDBLayer<D, Predicate, F>
Set a ProxyQueryPredicate that will be used
to possibly filter out proxies that according to the filters are correct,
but not according to the predicate.
Sourcepub fn with_username_formatter<Formatter>(
self,
f: Formatter,
) -> ProxyDBLayer<D, P, Formatter>
pub fn with_username_formatter<Formatter>( self, f: Formatter, ) -> ProxyDBLayer<D, P, Formatter>
Set an optional UsernameFormatter for
Basic-auth proxy usernames. It is called separately for each published
candidate, so routing labels can depend on that proxy’s metadata. Bearer
credentials and proxies without credentials are left unchanged.