pub enum ProxyFilterMode {
Optional,
Default,
Required,
Fallback(ProxyFilter),
}Expand description
The modus operandi to decide how to deal with a missing ProxyFilter in the Context
when selecting a Proxy from the ProxyDB.
More advanced behaviour can be achieved by combining one of these modi with another (custom) layer prepending the parent.
Variants
Optional
The ProxyFilter is optional, and if not present, no proxy is selected.
Default
The ProxyFilter is optional, and if not present, the default ProxyFilter is used.
Required
The ProxyFilter is required, and if not present, an error is returned.
Fallback(ProxyFilter)
The ProxyFilter is optional, and if not present, the provided fallback ProxyFilter is used.