pub struct Proxy {Show 18 fields
pub id: NonEmptyString,
pub address: ProxyAddress,
pub tcp: bool,
pub udp: bool,
pub http: bool,
pub https: bool,
pub socks5: bool,
pub socks5h: bool,
pub datacenter: bool,
pub residential: bool,
pub mobile: bool,
pub pool_id: Option<StringFilter>,
pub continent: Option<StringFilter>,
pub country: Option<StringFilter>,
pub state: Option<StringFilter>,
pub city: Option<StringFilter>,
pub carrier: Option<StringFilter>,
pub asn: Option<Asn>,
}Expand description
The selected proxy to use to connect to the proxy.
Fields
id: NonEmptyStringUnique identifier of the proxy.
address: ProxyAddressThe address to be used to connect to the proxy, including credentials if needed.
tcp: boolTrue if the proxy supports TCP connections.
udp: boolTrue if the proxy supports UDP connections.
http: boolhttp-proxy enabled
https: boolhttps-proxy enabled
socks5: boolsocks5-proxy enabled
socks5h: boolsocks5h-proxy enabled
datacenter: boolProxy is located in a datacenter.
residential: boolProxy’s IP is labeled as residential.
mobile: boolProxy’s IP originates from a mobile network.
pool_id: Option<StringFilter>Pool ID of the proxy.
continent: Option<StringFilter>Continent of the proxy.
country: Option<StringFilter>Country of the proxy.
state: Option<StringFilter>State of the proxy.
city: Option<StringFilter>City of the proxy.
carrier: Option<StringFilter>Mobile carrier of the proxy.
asn: Option<Asn>Autonomous System Number (ASN).
Implementations
Sourceimpl Proxy
impl Proxy
Sourcepub fn is_match(&self, ctx: &ProxyContext, filter: &ProxyFilter) -> bool
pub fn is_match(&self, ctx: &ProxyContext, filter: &ProxyFilter) -> bool
Check if the proxy is a match for the givenProxyContext and ProxyFilter.