pub struct ProxyDBService<S, D, P, F> { /* private fields */ }Expand description
A Service which selects a Proxy based on the given Context.
Depending on the ProxyFilterMode the selection proxies might be optional,
or use the default ProxyFilter in case none is defined.
A predicate can be used to provide additional filtering on the found proxies,
that otherwise did match the used ProxyFilter.
See the crate docs for examples and more info on the usage of this service.
Implementations
Sourceimpl<S, D> ProxyDBService<S, D, bool, ()>
impl<S, D> ProxyDBService<S, D, bool, ()>
Sourcepub const fn new(inner: S, db: D) -> Self
pub const fn new(inner: S, db: D) -> Self
Create a new ProxyDBService with the given inner Service and ProxyDB.
Sourceimpl<S, D, P, F> ProxyDBService<S, D, P, F>
impl<S, D, P, F> ProxyDBService<S, D, P, F>
Sourcepub fn filter_mode(self, mode: ProxyFilterMode) -> Self
pub fn filter_mode(self, mode: ProxyFilterMode) -> Self
Set a ProxyFilterMode to define the behaviour surrounding
ProxyFilter usage, e.g. if a proxy filter is required to be available or not,
or what to do if it is optional and not available.
Sourcepub fn set_filter_mode(&mut self, mode: ProxyFilterMode) -> &mut Self
pub fn set_filter_mode(&mut self, mode: ProxyFilterMode) -> &mut Self
Set a ProxyFilterMode to define the behaviour surrounding
ProxyFilter usage, e.g. if a proxy filter is required to be available or not,
or what to do if it is optional and not available.
Sourcepub const fn preserve_proxy(self, preserve: bool) -> Self
pub const fn preserve_proxy(self, preserve: bool) -> Self
Define whether or not an existing ProxyAddress (in the Context)
should be overwritten or not. By default preserve=false,
meaning we will overwrite the proxy address in case we selected one now.
NOTE even when preserve=false it might still be that there’s
a ProxyAddress in case it was set by a previous layer.
Sourcepub fn set_preserve_proxy(&mut self, preserve: bool) -> &mut Self
pub fn set_preserve_proxy(&mut self, preserve: bool) -> &mut Self
Define whether or not an existing ProxyAddress (in the Context)
should be overwritten or not. By default preserve=false,
meaning we will overwrite the proxy address in case we selected one now.
NOTE even when preserve=false it might still be that there’s
a ProxyAddress in case it was set by a previous layer.
Sourcepub fn select_predicate<Predicate>(
self,
p: Predicate,
) -> ProxyDBService<S, D, Predicate, F>
pub fn select_predicate<Predicate>( self, p: Predicate, ) -> ProxyDBService<S, D, Predicate, F>
Set a ProxyQueryPredicate that will be used
to possibly filter out proxies that according to the filters are correct,
but not according to the predicate.
Sourcepub fn username_formatter<Formatter>(
self,
f: Formatter,
) -> ProxyDBService<S, D, P, Formatter>
pub fn username_formatter<Formatter>( self, f: Formatter, ) -> ProxyDBService<S, D, P, Formatter>
Set a UsernameFormatter that will be used to format
the username based on the selected Proxy. This is required
in case the proxy is a router that accepts or maybe even requires
username labels to configure proxies further down/up stream.
Sourcepub fn into_inner(self) -> S
pub fn into_inner(self) -> S
Consumes self, returning the underlying service.